@@ -71,7 +71,8 @@ extracted_data = [
                 0.80162463698921349,
                 -0.20189357469900293,
                 90.0
-            ]
+            ],
+            'gold_standard': False
         }
     },
     {
@@ -109,7 +110,8 @@ extracted_data = [
                 1.9422413385414206,
                 -1.8834652410260238,
                 -2.663609178056995
-            ]
+            ],
+            'gold_standard': False
         }
     },
     {
@@ -175,7 +177,8 @@ extracted_data = [
                 3.1120077026469906,
                 1.272365186961546,
                 0.14045703217215191
-            ]
+            ],
+            'gold_standard': False
         }
     },
     {
@@ -289,7 +292,8 @@ extracted_data = [
                 8.2240070808507397,
                 0.57343422507612674,
                 3.2391978304671274
-            ]
+            ],
+            'gold_standard': False
         }
     },
     {
@@ -371,7 +375,8 @@ extracted_data = [
                 -0.83260148559900182,
                 -0.34062188619212308,
                 0.42514103064765579
-            ]
+            ],
+            'gold_standard': False
         }
     },
     {
@@ -381,11 +386,24 @@ extracted_data = [
                 'y': []
             },
             'text': [],
-            'slope': []
+            'slope': [],
+            'gold_standard': False
         }
     }
 ]
 
+kwargs_extra_data = {
+    'user_id': [
+        1,
+        2,
+        3,
+        4,
+        5,
+        6,
+        7
+    ]
+}
+
 processed_data = {
     'frame0': {
         'x': [
@@ -683,11 +701,162 @@ processed_data = {
             -0.83260148559900182,
             -0.34062188619212308,
             0.42514103064765579
+        ],
+        'gold_standard': [
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False,
+            False
+        ],
+        'data_index': [
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            0,
+            1,
+            1,
+            1,
+            2,
+            2,
+            2,
+            2,
+            2,
+            2,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            3,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            4,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5,
+            5
         ]
     }
 }
 
 reduced_data = {
+    'reducer': 'poly_line_text_reducer',
+    'low_consensus_lines': 8,
+    'transcribed_lines': 16,
     'frame0': [
         {
             'clusters_text': [
@@ -697,10 +866,16 @@ reduced_data = {
             'clusters_x': [883.6374999999999, 1282.5125000000003],
             'clusters_y': [127.12, 139.355],
             'consensus_score': 4.0,
+            'consensus_text': 'Pot Pourri',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 4,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False],
+            'user_ids': [1, 4, 5, 6],
+            'extract_index': [0, 0, 0, 0],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_text': [
@@ -712,10 +887,16 @@ reduced_data = {
             'clusters_x': [838.3525, 1439.145],
             'clusters_y': [273.3075, 274.9225],
             'consensus_score': 4.0,
+            'consensus_text': 'Gather as many rose',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 4,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False],
+            'user_ids': [2, 4, 5, 6],
+            'extract_index': [0, 1, 1, 1],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_text': [
@@ -727,10 +908,16 @@ reduced_data = {
             'clusters_x': [827.832, 1421.345],
             'clusters_y': [340.52799999999996, 338.09],
             'consensus_score': 4.75,
+            'consensus_text': 'leaves as you can',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 5,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False, False],
+            'user_ids': [2, 3, 4, 5, 6],
+            'extract_index': [1, 0, 2, 2, 2],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_text': [
@@ -742,25 +929,37 @@ reduced_data = {
             'clusters_x': [824.975, 1454.3625000000002],
             'clusters_y': [395.975, 384.53999999999996],
             'consensus_score': 3.75,
+            'consensus_text': 'just before the blooms',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 4,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False],
+            'user_ids': [3, 4, 5, 6],
+            'extract_index': [1, 3, 3, 3],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_text': [
-                ['are', '', 'are', 'are', '', 'are'],
+                ['are', '', 'are', 'are', '&', 'are'],
                 ['', 'going', 'going', '', '', 'going'],
-                ['', 'to', 'to', '', '&', 'to'],
+                ['', 'to', 'to', '', '', 'to'],
                 ['', '', 'fall', '', '', 'fall']
             ],
             'clusters_x': [819.36, 1344.815],
             'clusters_y': [461.305, 448.28499999999997],
             'consensus_score': 3.0,
+            'consensus_text': 'are going to fall',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 6,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False, False, False],
+            'user_ids': [3, 3, 4, 5, 5, 6],
+            'extract_index': [3, 4, 4, 4, 5, 4],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_text': [
@@ -773,10 +972,16 @@ reduced_data = {
             'clusters_x': [807.46, 1411.28],
             'clusters_y': [508.83666666666664, 500.505],
             'consensus_score': 2.0,
+            'consensus_text': '& mind only to use',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 3,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False],
+            'user_ids': [1, 4, 6],
+            'extract_index': [2, 5, 5],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_text': [
@@ -789,10 +994,16 @@ reduced_data = {
             'clusters_x': [813.5733333333334, 1392.285],
             'clusters_y': [566.2200000000001, 552.72],
             'consensus_score': 2.8,
+            'consensus_text': 'pink or red & to',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 4,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False],
+            'user_ids': [3, 4, 5, 6],
+            'extract_index': [5, 6, 6, 6],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_text': [
@@ -804,10 +1015,16 @@ reduced_data = {
             'clusters_x': [815.3275, 1431.1666666666667],
             'clusters_y': [630.3525, 611.5733333333334],
             'consensus_score': 3.25,
+            'consensus_text': 'get them when they',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 4,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False],
+            'user_ids': [3, 4, 5, 6],
+            'extract_index': [2, 7, 8, 7],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_text': [
@@ -819,10 +1036,16 @@ reduced_data = {
             'clusters_x': [815.1766666666666, 1433.716666666667],
             'clusters_y': [683.7599999999999, 680.4133333333334],
             'consensus_score': 2.75,
+            'consensus_text': 'are quite dry put',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 5,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False, False],
+            'user_ids': [1, 4, 5, 5, 6],
+            'extract_index': [4, 8, 9, 10, 8],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_text': [
@@ -833,10 +1056,16 @@ reduced_data = {
             'clusters_x': [815.4733333333334, 1418.6966666666667],
             'clusters_y': [739.5300000000001, 747.7033333333334],
             'consensus_score': 3.0,
+            'consensus_text': 'them on a tray',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 3,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False],
+            'user_ids': [4, 5, 6],
+            'extract_index': [9, 11, 9],
+            'low_consensus': False,
+            'flagged': False
         },
         {
             'clusters_text': [
@@ -849,10 +1078,16 @@ reduced_data = {
             'clusters_x': [812.86, 1469.27],
             'clusters_y': [800.1466666666666, 826.4449999999999],
             'consensus_score': 2.8,
+            'consensus_text': 'to dry in a conservatory',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 3,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False],
+            'user_ids': [4, 5, 6],
+            'extract_index': [10, 12, 10],
+            'low_consensus': True,
+            'flagged': True
         },
         {
             'clusters_text': [
@@ -864,10 +1099,17 @@ reduced_data = {
             'clusters_x': [815.045, 1327.74],
             'clusters_y': [850.88, 850.7],
             'consensus_score': 1.75,
+            'consensus_text': 'or hot house &',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 3,
-            'slope_label': 0},
+            'slope_label': 0,
+            'gold_standard': [False, False, False],
+            'user_ids': [5, 5, 6],
+            'extract_index': [13, 23, 16],
+            'low_consensus': True,
+            'flagged': True
+        },
         {
             'clusters_text': [
                 ['then', 'them', 'them'],
@@ -878,10 +1120,17 @@ reduced_data = {
             'clusters_x': [817.3366666666667, 1447.2800000000002],
             'clusters_y': [909.73, 934.2650000000001],
             'consensus_score': 2.0,
+            'consensus_text': 'them once or twice',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 3,
-            'slope_label': 0},
+            'slope_label': 0,
+            'gold_standard': [False, False, False],
+            'user_ids': [4, 5, 6],
+            'extract_index': [11, 24, 11],
+            'low_consensus': True,
+            'flagged': True
+        },
         {
             'clusters_text': [
                 ['every', 'every'],
@@ -890,10 +1139,17 @@ reduced_data = {
             'clusters_x': [819.755, 1117.335],
             'clusters_y': [963.015, 956.645],
             'consensus_score': 2.0,
+            'consensus_text': 'every day',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 2,
-            'slope_label': 0},
+            'slope_label': 0,
+            'gold_standard': [False, False],
+            'user_ids': [5, 6],
+            'extract_index': [15, 12],
+            'low_consensus': True,
+            'flagged': True
+        },
         {
             'clusters_text': [
                 ['dry', 'dry'],
@@ -904,10 +1160,17 @@ reduced_data = {
             'clusters_x': [815.25, 1452.74],
             'clusters_y': [1015.4, 1020.78],
             'consensus_score': 1.5,
+            'consensus_text': 'dry then put in',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 2,
-            'slope_label': 0},
+            'slope_label': 0,
+            'gold_standard': [False, False],
+            'user_ids': [5, 6],
+            'extract_index': [16, 14],
+            'low_consensus': True,
+            'flagged': True
+        },
         {
             'clusters_text': [
                 ['a', 'a', 'a', 'a'],
@@ -919,12 +1182,30 @@ reduced_data = {
             'clusters_x': [811.6225, 1455.3375],
             'clusters_y': [1088.7925, 1088.0325],
             'consensus_score': 4.0,
+            'consensus_text': 'a jar with a cover',
             'gutter_label': 1,
             'line_slope': 0.09112619119034585,
             'number_views': 4,
-            'slope_label': 0
+            'slope_label': 0,
+            'gold_standard': [False, False, False, False],
+            'user_ids': [1, 4, 5, 6],
+            'extract_index': [7, 12, 17, 15],
+            'low_consensus': False,
+            'flagged': False
         }
-    ]
+    ],
+    'parameters': {
+        'eps_slope': 0.5,
+        'eps_line': 15.0,
+        'eps_word': 30.0,
+        'gutter_tol': 0.0,
+        'min_samples': 2,
+        'dot_freq': 'line',
+        'min_word_count': 1,
+        'low_consensus_threshold': 3.0,
+        'process_by_line': False,
+        'minimum_views': 5
+    }
 }
 
 TestSWReducer = ReducerTest(
@@ -935,15 +1216,115 @@ TestSWReducer = ReducerTest(
     reduced_data,
     'Test SW text reducer',
     okwargs={
-        'metric': 'euclidean',
-        'gutter_tol': 0,
-        'min_word_count': 1
+        'gutter_tol': 0.0,
+        'min_word_count': 1,
+        'low_consensus_threshold': 3.0,
+        'minimum_views': 5
     },
     kwargs={
         'eps_slope': 0.5,
-        'eps_line': 15,
-        'eps_word': 30,
+        'eps_line': 15.0,
+        'eps_word': 30.0,
         'dot_freq': 'line',
         'min_samples': 2
+    },
+    network_kwargs=kwargs_extra_data,
+    output_kwargs=True,
+    test_name='TestSWReducer'
+)
+
+extracted_data_all_blank = [
+    {
+        'frame0': {
+            'text': [],
+            'slope': [],
+            'points': {
+                'x': [],
+                'y': []
+            }
+        }
+    },
+    {
+        'frame0': {
+            'text': [],
+            'slope': [],
+            'points': {
+                'x': [],
+                'y': []
+            }
+        }
+    },
+    {
+        'frame0': {
+            'text': [],
+            'slope': [],
+            'points': {
+                'x': [],
+                'y': []
+            }
+        }
     }
+]
+
+kwargs_extra_data_all_blank = {
+    'user_id': [
+        1,
+        2,
+        None
+    ]
+}
+
+processed_data_all_blank = {
+    'frame0': {
+        'x': [],
+        'y': [],
+        'text': [],
+        'slope': [],
+        'gold_standard': [],
+        'data_index': []
+    }
+}
+
+reduced_data_all_blank = {
+    'reducer': 'poly_line_text_reducer',
+    'low_consensus_lines': 0,
+    'transcribed_lines': 0,
+    'frame0': [],
+    'parameters': {
+        'eps_slope': 0.5,
+        'eps_line': 15.0,
+        'eps_word': 30.0,
+        'gutter_tol': 0.0,
+        'min_samples': 2,
+        'dot_freq': 'line',
+        'min_word_count': 1,
+        'low_consensus_threshold': 3.0,
+        'process_by_line': False,
+        'minimum_views': 5
+    }
+}
+
+TestSWReducerAllBlank = ReducerTest(
+    poly_line_text_reducer,
+    process_data,
+    extracted_data_all_blank,
+    processed_data_all_blank,
+    reduced_data_all_blank,
+    'Test SW text reducer when all extracts are blank',
+    okwargs={
+        'gutter_tol': 0.0,
+        'min_word_count': 1,
+        'low_consensus_threshold': 3.0,
+        'minimum_views': 5
+    },
+    kwargs={
+        'eps_slope': 0.5,
+        'eps_line': 15.0,
+        'eps_word': 30.0,
+        'dot_freq': 'line',
+        'min_samples': 2
+    },
+    network_kwargs=kwargs_extra_data_all_blank,
+    output_kwargs=True,
+    test_name='TestSWReducerAllBlank'
 )
